Learn R Programming

starvars (version 1.1.11)

print.VLSTAR: Print method for objects of class VLSTAR

Description

print’ methods for class ‘VLSTAR’.

Usage

# S3 method for VLSTAR
print(x, ...)

Value

Print of VLSTAR results

Arguments

x

An object of class ‘VLSTAR’ obtained through VLSTAR().

...

further arguments to be passed to and from other methods

Author

Andrea Bucci

References

Terasvirta T. and Yang Y. (2014), Specification, Estimation and Evaluation of Vector Smooth Transition Autoregressive Models with Applications. CREATES Research Paper 2014-8

See Also

VLSTAR