Learn R Programming

starvars (version 1.1.11)

summary.VLSTAR: Summary method for objects of class VLSTAR

Description

summary’ methods for class ‘VLSTAR’.

Usage

# S3 method for VLSTAR
summary(object, ...)

# S3 method for summary.VLSTAR print(x, ...)

Value

An object of class summary.VLSTAR containing a list of summary information from VLSTAR estimates. When print is applied to this object, summary information are printed

Arguments

object

An object of class ‘VLSTAR’ obtained through VLSTAR().

...

further arguments to be passed to and from other methods

x

A summary object of class ‘VLSTAR’ obtained through summary().

Methods (by generic)

  • print(summary.VLSTAR): Print of the summary

Author

Andrea Bucci

References

Terasvirta T. and Yang Y. (2014), Specification, Estimation and Evaluation of Vector Smooth Transition Autoregressive Models with Applications. CREATES Research Paper 2014-8

See Also

VLSTAR