Learn R Programming

starvars (version 1.1.11)

techprices: Daily closing prices of 3 tech stocks.

Description

This data set contains the series of daily prices of Google, Microsof and Amazon stocks from January 3, 2005 to June 16, 2020, gathered from Yahoo.

Usage

data("techprices")

Arguments

Format

An xts object with 3890 daily observations, ranging from from January 3, 2005 to June 16, 2020.

Googledaily closing prices of Google (GOOG) stock.
Microsoftdaily closing prices of Microsoft (MSFT) stock.
Amazondaily closing stock prices of Amazon (AMZN) stock.

Author

Andrea Bucci