‘summary’ methods for class ‘VLSTAR’.
# S3 method for VLSTAR
summary(object, ...)# S3 method for summary.VLSTAR
print(x, ...)
An object of class summary.VLSTAR containing a list of summary information from VLSTAR estimates. When print is applied to this object, summary information are printed
An object of class ‘VLSTAR’ obtained through VLSTAR().
further arguments to be passed to and from other methods
A summary object of class ‘VLSTAR’ obtained through summary().
print(summary.VLSTAR): Print of the summary
Andrea Bucci
Terasvirta T. and Yang Y. (2014), Specification, Estimation and Evaluation of Vector Smooth Transition Autoregressive Models with Applications. CREATES Research Paper 2014-8
VLSTAR